@@ -1,6 +1,8 @@
 import os
 import requests
 
+from crono_api_client import utils
+
 API_URL = os.getenv('CRONO_API_URL')
 API_KEY = os.getenv('CRONO_API_KEY')
 
@@ -80,22 +82,18 @@ class Job:
 
 	# Triggers
 
-	def on(self, *args, **kwargs):
-		self.trigger = {'name': 'on', 'args': args, 'kwargs': kwargs}
+	def on(self, datetime_):
+		self.trigger = triggers.on(datetime_)
 		return self.send()
 
-	def after(self, *args, **kwargs):
-		self.trigger = {'name': 'after', 'args': args, 'kwargs': kwargs}
+	def after(self, hours=None, minutes=None, seconds=None):
+		self.trigger = triggers.after(hours=hours, minutes=minutes, seconds=seconds)
 		return self.send()
 
-	def every(self, *args, **kwargs):
-		self.trigger = {'name': 'every', 'args': args, 'kwargs': kwargs}
+	def every(self, hours=None, minutes=None, seconds=None):
+		self.trigger = triggers.every(hours=hours, minutes=minutes, seconds=seconds)
 		return self.send()
 
-	def cron(self, *args, **kwargs):
-		self.trigger = {'name': 'cron', 'args': args, 'kwargs': kwargs}
-		return self.send()
-
-	def at(self, *args, **kwargs):
-		self.trigger = {'name': 'at', 'args': args, 'kwargs': kwargs}
+	def cron(self, expression):
+		self.trigger = triggers.cron(expression)
 		return self.send()
